# -*- coding: utf-8 -*-

import json
import shutil
from .exceptions import CyberarkException, CyberarkAPIException
from .abstract import Bastion


class Platform:
    def __init__(self, epv: Bastion):
        self.epv = epv
        self.session = self.epv.session

    def get_platforms(self, active: bool=None, systemType: str=  None, periodicVerify: bool=None, manualVerify: bool=None,
                      periodicChange: bool = None, manualChange: bool = None, automaticReconcile: bool = None,
                      manualReconcile: bool = None):

        search = "Filter="
        add_and = False
        if active is not None:
            search += "active eq " + str(active)
            add_and = True
        if systemType is not None:
            if add_and: search += " AND "
            search += "systemType eq " + systemType
            add_and = True
        if periodicVerify is not None:
            if add_and: search += " AND "
            search += "perodicVerify eq" + str(periodicVerify)
            add_and = True
        if manualVerify is not None:
            if add_and: search += " AND "
            search += "manualVerify eq" + str(manualVerify)
            add_and = True
        if periodicChange is not None:
            if add_and: search += " AND "
            search += "periodicChange eq" + str(periodicChange)
            add_and = True
        if manualChange is not None:
            if add_and: search += " AND "
            search += "manualChange eq" + str(manualChange)
            add_and = True
        if automaticReconcile is not None:
            if add_and: search += " AND "
            search += "automaticReconcile eq" + str(automaticReconcile)
            add_and = True
        if manualReconcile is not None:
            if add_and: search += " AND "
            search += "automaticReconcile eq" + str(automaticReconcile)

        if search == 'Filter=':
            url, head = self.epv.get_url("API/Platforms/Targets")
        else:
            url, head = self.epv.get_url("API/Platforms/Targets/" + search)

        try:
            req = self.session.get(url, headers=head, **self.epv.request_params)
        except Exception as err:
            # uncatched exception
            raise CyberarkException(err)

        if req.status_code != 200:
            content = json.loads(req.content)
            raise CyberarkAPIException(content)

        platforms = json.loads(req.content)
        return platforms["Platforms"]


    def get_platforms_details(self, plateform_name: str):
        url, head = self.epv.get_url("API/Platforms/" + plateform_name)

        try:
            req = self.session.get(url, headers=head, **self.epv.request_params)
        except Exception as err:
            # uncatched exception
            raise CyberarkException(err)

        if req.status_code != 200:
            content = json.loads(req.content)
            raise CyberarkAPIException(content)

        platforms = json.loads(req.content)
        return platforms


    def del_plaform(self, pfid):
        url, head = self.epv.get_url("API/Platforms/Targets/"+str(pfid))

        try:
            req = self.session.delete(url, headers=head, **self.epv.request_params)
            #req = epv.session.get(url, headers=head, params=data, **self.epv.reqparms)
        except Exception as err:
            # uncatched exception
            raise CyberarkException(err)

        if req.status_code != 204:
            content = json.loads(req.content)
            #raise CyberarkAPIException(content["ErrorMessage"])
            raise CyberarkAPIException(content)

        return True

    def export_platform(self, pfid: str, outdir: str):
        """Export platform files to outdir (existing directory)"""
        url, head = self.epv.get_url("API/Platforms/"+str(pfid)+"/Export")

        try:
            req = self.session.post(url, headers=head, data=None, **self.epv.request_params, stream=True)
        except Exception as err:
            # uncatched exception
            raise CyberarkException(err)

        if req.status_code != 200:
            content = json.loads(req.content)
            raise CyberarkAPIException(content["Message"])

        with open(outdir+"/"+pfid+".zip", "wb") as pf_file:
            shutil.copyfileobj(req.raw, pf_file)

        return True

    def get_session_management_policy(self, platformId):
        url, head = self.epv.get_url('API/Platforms/Targets/' + str(platformId) + '/PrivilegedSessionManagement')
        try:
            req = self.epv.session.get(url, **self.epv.request_params)
        except Exception as err:
            # uncatched exception
            raise CyberarkException(err)

        if req.status_code != 200:
            content = json.loads(req.content)
            raise CyberarkAPIException(content["ErrorMessage"])
        
        return json.loads(req.content)
        

