from .abstract import Bastion
import json

class User:
    def __init__(self, epv: Bastion):
        self.epv = epv

    def get_user_details(self, id: int):
        pass

    def get_users(self, pattern: str = None, filter: str = None):
        assert filter in (None, "userType", "componentUser")
        data = {}

        if filter is not None:
            data["filter"] = filter

        if pattern is not None:
            data["search"] = pattern

        url, head = self.epv.get_url('api/Users')
        req = self.epv.session.get(url, headers=head, params=data, **self.epv.request_params)

        if req.status_code == 200:
            return json.loads(req.content)
        elif req.status_code == 404:
            return False
        else:
            raise Exception("Error occured during get_members call. CyberArk error:", req.content)


class Group:
    def __init__(self, epv: Bastion):
        self.epv = epv

    def get_groups(self, pattern: str = None, group_type: str = None):
        payload = {}

        if group_type is not None:
            group_type = "groupeType eq " + group_type
            payload["filer"] = group_type
        if pattern is not None:
            payload["search"] = pattern

        url, head = self.epv.get_url('api/UserGroups')
        req = self.epv.session.get(url, headers=head, params=payload, **self.epv.request_params)

        if req.status_code == 200:
            return json.loads(req.content)
        elif req.status_code == 404:
            return False
        else:
            raise Exception("Error occured during get_members call. CyberArk error:", req.content)

